@@ -303,8 +303,8 @@ class AbstractMirrorComponent(Component):
         self.__phi = Param("phi", self, SIfloat(phi), canFsig=True, fsig_name="phase")
         self.__Rcx = AttrParam("Rcx", self, SIfloat(Rcx))
         self.__Rcy = AttrParam("Rcy", self, SIfloat(Rcy))
-        self.__xbeta = AttrParam("xbeta", self, SIfloat(xbeta), canFsig=True, fsig_name="x")
-        self.__ybeta = AttrParam("ybeta", self, SIfloat(ybeta), canFsig=True, fsig_name="y")
+        self.__xbeta = AttrParam("xbeta", self, SIfloat(xbeta), canFsig=True, fsig_name="xbeta")
+        self.__ybeta = AttrParam("ybeta", self, SIfloat(ybeta), canFsig=True, fsig_name="ybeta")
         self.__mass = AttrParam("mass", self, SIfloat(mass))
         self.__Ix = AttrParam("Ix", self, SIfloat(Ix))
         self.__Iy = AttrParam("Iy", self, SIfloat(Iy))
@@ -321,6 +321,11 @@ class AbstractMirrorComponent(Component):
         self.__Frx = Param("Frx", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="Frx")
         self.__Fry = Param("Fry", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="Fry")
         
+        self.__Fs0 = Param("Fs0", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="Fs0")
+        self.__Fs1 = Param("Fs1", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="Fs1")
+        self.__Fs0 = Param("s0", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="s0")
+        self.__Fs1 = Param("s1", self, None, canFsig=True, isPutable=False, isPutter=False, isTunable=False, fsig_name="s1")
+            
         self._default_fsig_param = self.__phi
         
     @property
@@ -541,7 +546,7 @@ class mirror(AbstractMirrorComponent):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/mirror_flat.svg", self ,[(-4,15,self.nodes[0]), (14,15,self.nodes[1])])
             
         return self._svgItem
@@ -647,7 +652,7 @@ class beamSplitter(AbstractMirrorComponent):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             # FIXME: make proper SVG component for beam splitter
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/mirror_flat.svg", self ,[(-4,24,self.nodes[0]), (-4,6,self.nodes[1]), (14,6,self.nodes[2]), (14,24,self.nodes[3])])
             
@@ -757,7 +762,7 @@ class space(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._QItem == None:
+        if self._QItem is None:
             self._QItem = pykat.gui.graphics.SpaceQGraphicsItem(self)
         
         return self._QItem
@@ -890,19 +895,20 @@ class grating(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.SpaceQGraphicsItem(self) # TODO: make SVG graphic for grating
         
         return self._svgItem
 
 class isolator(Component):
-    def __init__(self, name, node1, node2, S = 0, node3="dump"):
+    def __init__(self, name, node1, node2, S = 0, node3="dump", option=0):
         Component.__init__(self, name)
         
         self._requested_node_names.append(node1)
         self._requested_node_names.append(node2)
         self._requested_node_names.append(node3)
         self._svgItem = None
+        self._option = option
         
         self.__S = Param("S",self,SIfloat(S))
         
@@ -915,20 +921,30 @@ class isolator(Component):
     def parseFinesseText(text):
         values = text.split()
 
-        if values[0] != "isol":
+        if values[0] != "isol" and values[0] != "isol*":
             raise pkex.BasePyKatException("'{0}' not a valid Finesse isolator command".format(text))
 
+        if values[0].endswith('*'):
+            option = 1
+        else:
+            option = 0
+            
         values.pop(0) # remove initial value
         
         if len(values) == 4:
-            return isolator(values[0], values[2], values[3], values[1])
+            return isolator(values[0], values[2], values[3], values[1], option=option)
         elif len(values) == 5:
-            return isolator(values[0], values[2], values[3], node3=values[4], S=values[1])
+            return isolator(values[0], values[2], values[3], node3=values[4], S=values[1], option=option)
         else:
             raise pkex.BasePyKatException("Isolator Finesse code format incorrect '{0}'".format(text))
         
     def getFinesseText(self):
-        rtn = ['isol {0} {1} {2} {3} {4}'.format(self.name, self.S.value, self.nodes[0].name, self.nodes[1].name, self.nodes[2].name)]
+        if self._option == 0:
+            cmd = "isol"
+        elif self._option == 1:
+            cmd = "isol*"
+            
+        rtn = ['{cmd} {0} {1} {2} {3} {4}'.format(self.name, self.S.value, self.nodes[0].name, self.nodes[1].name, self.nodes[2].name, cmd=cmd)]
         
         for p in self._params:
             rtn.extend(p.getFinesseText())
@@ -965,7 +981,7 @@ class isolator(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/isolator.svg", self ,[(-4,15,self.nodes[0]), (14,15,self.nodes[1]), (14,24,self.nodes[2])])
         
         return self._svgItem
@@ -978,11 +994,30 @@ class lens(Component):
         self._requested_node_names.append(node2)
         self._svgItem = None
         self.__f = Param("f", self, SIfloat(f))
+        self.__p = Param("p", self, None)
         
     @property
-    def f(self): return self.__f
+    def f(self):
+        if self.__f is not None:
+            return self.__f
+        else:
+            return 1/self.__p
     @f.setter
-    def f(self, value): self.__f.value = SIfloat(value)
+    def f(self, value):
+        self.__f.value = SIfloat(value)
+        self.__p.value = None
+    
+    @property
+    def p(self):
+        if self.__p is not None:
+            return self.__p
+        else:
+            return 1/self.__f
+            
+    @f.setter
+    def p(self, value):
+        self.__p.value = SIfloat(value)
+        self.__f.value = None
     
     @staticmethod
     def parseFinesseText(text):
@@ -999,7 +1034,10 @@ class lens(Component):
             raise pkex.BasePyKatException("Lens Finesse code format incorrect '{0}'".format(text))
         
     def getFinesseText(self):
-        rtn = ['lens {0} {1} {2} {3}'.format(self.name, self.f.value, self.nodes[0].name, self.nodes[1].name)]
+        if self.__p is None:
+            rtn = ['lens {0} {1} {2} {3}'.format(self.name, self.f.value, self.nodes[0].name, self.nodes[1].name)]
+        else:
+            rtn = ['lens* {0} {1} {2} {3}'.format(self.name, self.p.value, self.nodes[0].name, self.nodes[1].name)]
         
         for p in self._params:
             rtn.extend(p.getFinesseText())
@@ -1035,7 +1073,7 @@ class lens(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/lens.svg", self ,[(-4,15,self.nodes[0]), (14,15,self.nodes[1])])
         
         return self._svgItem
@@ -1047,10 +1085,11 @@ class modulator(Component):
         self._requested_node_names.append(node1)
         self._requested_node_names.append(node2)
         self._svgItem = None
-        self.__f = Param("f", self, SIfloat(f))
+        self.__f = Param("f", self, SIfloat(f), canFsig=True, fsig_name="fre")
         self.__midx = Param("midx", self, SIfloat(midx))
         self.__phase = Param("phase", self, SIfloat(phase), canFsig=True, fsig_name="phase")
-        self.__order = order
+        self.__order = 0
+        self.order = order
         self.type = modulation_type
         
         self._default_fsig_param = self.__phase
@@ -1074,17 +1113,28 @@ class modulator(Component):
     def order(self): return self.__order
     @order.setter
     def order(self, value):
-        if value <= 1 and value > 6:
-            raise pkex.BasePyKatException("modulator order must be between 1 and 6")
+        
+        try:
+            value = int(value)
             
-        self.__order = int(value)
+            if value <= 1 and value > 6:
+                raise pkex.BasePyKatException("modulator order must be between 1 and 6 or 's' for single sideband")
+                
+        except ValueError:
+            if value != 's' or (isinstance(value, int) and  value <= 1 and value > 6):
+                raise pkex.BasePyKatException("modulator order must be between 1 and 6 or 's' for single sideband")
+
+        self.__order = value
+        
     
     @property 
     def type(self): return self.__type
     @type.setter
     def type(self, value):
-        if value != "am" and value != "pm":
-            raise pkex.BasePyKatException("Modulator type must be am (amplitude modulation) or pm (phase modulation)")
+        accepted = ["am", "pm", "yaw", "pitch"]
+        
+        if value not in accepted:
+            raise pkex.BasePyKatException("Modulator type must be: " + ", ".join(accepted))
             
         self.__type = str(value)
     
@@ -1141,7 +1191,7 @@ class modulator(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/modulator.svg", self ,[(-4,15,self.nodes[0]), (14,15,self.nodes[1])])
         
         return self._svgItem
@@ -1153,7 +1203,7 @@ class laser(Component):
         self._requested_node_names.append(node)
         
         self.__power = Param("P", self, SIfloat(P), canFsig=True, fsig_name="amp")
-        self.__f_offset = Param("f", self, SIfloat(f), canFsig=True, fsig_name="f")
+        self.__f_offset = Param("f", self, SIfloat(f), canFsig=True, fsig_name="freq")
         self.__phase = Param("phase", self, SIfloat(phase), canFsig=True, fsig_name="phase")
         self.__noise = AttrParam("noise", self, None)
         self._svgItem = None
@@ -1233,7 +1283,7 @@ class laser(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/laser.svg", self, [(65,25,self.nodes[0])])
             
         return self._svgItem
@@ -1299,7 +1349,7 @@ class squeezer(Component):
         if not USE_GUI:
             raise NoGUIException
             
-        if self._svgItem == None:
+        if self._svgItem is None:
             self._svgItem = pykat.gui.graphics.ComponentQGraphicsItem(":/resources/laser.svg", self, [(65,25,self.nodes[0])])
             
         return self._svgItem
